/**
  ******************************************************************************
  * @file    Blinky.c
  * @author  Julian Friedrich
  * @version 1.0 (Based on STM Sample)
  * @date    23/10/2009
  * @brief   Main program body.
  ******************************************************************************
  *
  * You can use and copy this file freely, but without any waranty.
  *
  */

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"

/* Private function prototypes -----------------------------------------------*/
void RCC_Configuration(void);
void Delay(__IO uint32_t nCount);
void Basic_GPIO_init(void);

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;

	RCC_Configuration();										/* System Clocks Configuration */
	Basic_GPIO_init();

	/* Initialize Leds mounted on EVAL board */
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB, ENABLE);		/* Enable GPIOB clock */
	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_All;					/* modify entire Port */
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;			/* Set port mode to push pull*/
	GPIO_InitStructure.GPIO_Speed = GPIO_Speed_10MHz;			/* Set Port speed to 10Mhz */
	GPIO_Init(GPIOB, &GPIO_InitStructure);						/* Configure Port*/

	while (1)
	{
		GPIO_SetBits(GPIOB, GPIO_Pin_All);						/* Turn LEDs on*/
		Delay(0x4FFFF);											/* Insert delay */
		GPIO_ResetBits(GPIOB, GPIO_Pin_All);					/* Turn LEDs off */
		Delay(0xFFFFF);											/* Insert delay */
	}
}

/**
  * @brief  Configures the different system clocks.
  * @param  None
  * @retval None
  */
void RCC_Configuration(void)
{
	/* Setup the microcontroller system. Initialize the Embedded Flash Interface,
       initialize the PLL and update the System Frequency variable. */
	SystemInit();
}

/**
  * @brief  Sets all GPIOS to a defined input state to reduce the power consumption and avoid EMI/EMC.
  * @param  None
  * @retval None
  */
void Basic_GPIO_init(void)
{
	GPIO_InitTypeDef GPIO_InitStructure;

	/* Turn on peripheral clock for the GPIO ports*/
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB |
						   RCC_APB2Periph_GPIOC | RCC_APB2Periph_GPIOD |
                           RCC_APB2Periph_GPIOE | RCC_APB2Periph_GPIOF |
                           RCC_APB2Periph_GPIOG , ENABLE);

	GPIO_InitStructure.GPIO_Pin = GPIO_Pin_All;		/* modify entire Port*/
	GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;	/* Set port mode to input */

	GPIO_Init(GPIOA, &GPIO_InitStructure);			/* Configure Port A */
	GPIO_Init(GPIOB, &GPIO_InitStructure);			/* Configure Port B */
	GPIO_Init(GPIOC, &GPIO_InitStructure);			/* Configure Port C */
	GPIO_Init(GPIOD, &GPIO_InitStructure);			/* Configure Port D */
	GPIO_Init(GPIOE, &GPIO_InitStructure);			/* Configure Port E */
	GPIO_Init(GPIOF, &GPIO_InitStructure);			/* Configure Port F */
	GPIO_Init(GPIOG, &GPIO_InitStructure);			/* Configure Port G */

	/* Turn off peripheral clock for the GPIO ports*/
	RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_GPIOB |
						   RCC_APB2Periph_GPIOC | RCC_APB2Periph_GPIOD |
						   RCC_APB2Periph_GPIOE | RCC_APB2Periph_GPIOF |
                           RCC_APB2Periph_GPIOG , DISABLE);
}

/**
  * @brief  Inserts a delay time.
  * @param  nCount: specifies the delay time length.
  * @retval None
  */
void Delay(__IO uint32_t nCount)
{
	for(; nCount != 0; nCount--);
}
